@@ -17,19 +17,17 @@ __docformat__ = 'google'
 # Expose certain names at top-level.
 
 from icepool.die.func import (standard, d, __getattr__, bernoulli, coin,
-                              from_cweights, from_sweights, from_rv, align,
-                              align_range, reduce, accumulate, apply)
+                              from_cweights, from_sweights, from_rv,
+                              min_outcome, max_outcome, align, align_range,
+                              reduce, accumulate, apply)
 
 from icepool.die.die import Die
 
-highest = Die.highest
-lowest = Die.lowest
-max_outcome = Die.max_outcome
-min_outcome = Die.min_outcome
+from icepool.die.keep import lowest, highest
 
 from icepool.pool.base import PoolBase
 from icepool.pool.pool import Pool, standard_pool
-from icepool.pool.eval import EvalPool, WrapFuncEval, JointEval, SumPool, sum_pool, FindBestSet, FindBestRun
+from icepool.pool.eval import EvalPool, WrapFuncEval, JointEval, SumPool, sum_pool, enumerate_pool, FindBestSet, FindBestRun
 from icepool.pool.roll import PoolRoll  # Not used externally.
 
 import enum
@@ -46,7 +44,7 @@ Reroll = SpecialValue.Reroll
 __all__ = [
     'standard', 'd', 'bernoulli', 'coin', 'Die', 'from_cweights',
     'from_sweights', 'from_rv', 'align', 'align_range', 'lowest', 'highest',
-    'max_outcome', 'min_outcome', 'reduce', 'accumulate', 'apply', 'Reroll',
+    'min_outcome', 'max_outcome', 'reduce', 'accumulate', 'apply', 'Reroll',
     'PoolBase', 'Pool', 'standard_pool', 'EvalPool', 'WrapFuncEval',
-    'JointEval', 'SumPool', 'sum_pool', 'FindBestSet', 'FindBestRun'
+    'JointEval', 'SumPool', 'FindBestSet', 'FindBestRun'
 ]
