@@ -127,6 +127,16 @@ def from_rv(rv, outcomes, denominator, **kwargs):
     return from_cweights(outcomes, cweights)
 
 
+def min_outcome(*dice):
+    """Returns the minimum possible outcome among the dice. """
+    return min(die.outcomes()[0] for die in dice)
+
+
+def max_outcome(*dice):
+    """Returns the maximum possible outcome among the dice. """
+    return max(die.outcomes()[-1] for die in dice)
+
+
 def align(*dice):
     """Pads dice with zero weights so that all have the same set of outcomes.
 
@@ -173,6 +183,7 @@ def reduce(func, dice, *, initial=None):
         initial: If provided, this will be placed at the front of the sequence
             of dice.
     """
+    # Conversion to dice is not necessary since apply() takes care of that.
     iter_dice = iter(dice)
     if initial is not None:
         result = initial
@@ -203,6 +214,7 @@ def accumulate(func, dice, *, initial=None):
         initial: If provided, this will be placed at the front of the sequence
             of dice.
     """
+    # Conversion to dice is not necessary since apply() takes care of that.
     iter_dice = iter(dice)
     if initial is not None:
         result = initial
