@@ -15,7 +15,7 @@ class PoolBase(ABC):
     * `Pool`, which represents a pool of dice with random results.
     * `PoolRoll`, which represents a single, fixed roll of a pool.
         `PoolRoll` is only needed internally, as external dicts and sequences
-        will be implicitly cast to `PoolRoll` in `EvalPool.eval()`.
+        will be implicitly converted to `PoolRoll` in `EvalPool.eval()`.
     """
 
     @abstractmethod
