@@ -13,13 +13,13 @@ def _is_dict(arg):
         arg, '__getitem__')
 
 
-class PoolRoll(icepool.BasePool):
+class PoolRoll(icepool.PoolBase):
     """Represents a single, fixed roll of a dice pool.
 
-    Like `DicePool`, this may be used as an argument to `EvalPool`.
+    Like `Pool`, this may be used as an argument to `EvalPool`.
 
     `PoolRoll` is only needed internally, as external dicts and sequences
-    will be implicitly cast to `PoolRoll` in `EvalPool.eval()`.
+    will be implicitly converted to `PoolRoll` in `EvalPool.eval()`.
     """
 
     def __init__(self, arg, /):
